/*
                             Recycle Bin Recover
 */

#ifndef EDV_RECBIN_RECOVER_H
#define EDV_RECBIN_RECOVER_H

#include <gtk/gtk.h>

#include "edv_types.h"
#include "edv_recycled_obj.h"


extern const gchar *EDVRecBinRecoverGetError(edv_core_struct *core);

extern gint EDVRecBinRecover(
	edv_core_struct *core,
	const guint index,
	const gchar *alternate_recovery_path,
	gchar **new_obj_rtn,
	GtkWidget *toplevel,
	gboolean show_progress, gboolean interactive,
	gboolean *yes_to_all
);


#endif	/* EDV_RECBIN_RECOVER_H */
